@@ -57,10 +57,6 @@ Useful definitions:
  4    1   5   L=J+1 , S=1              4^++     \-                                        30qq9
 ==== === === ======================== ======== ================= ====================== =======================
 
-References
-----------
-
-HepPDT and HepPID versions 3.04.01: http://lcgapp.cern.ch/project/simu/HepPDT/
 """
 
 from __future__ import absolute_import
@@ -68,17 +64,24 @@ from __future__ import absolute_import
 from .functions import is_valid
 from .functions import abspid
 
+from .functions import is_quark
 from .functions import is_lepton
 from .functions import is_hadron
 from .functions import is_meson
 from .functions import is_baryon
-from .functions import is_diquark
-from .functions import is_nucleus
 from .functions import is_pentaquark
+from .functions import is_gauge_boson_or_higgs
+from .functions import is_sm_gauge_boson_or_higgs
+from .functions import is_generator_specific
+from .functions import is_special_particle
+from .functions import is_nucleus
+from .functions import is_diquark
 from .functions import is_Rhadron
 from .functions import is_Qball
 from .functions import is_dyon
 from .functions import is_SUSY
+from .functions import is_technicolor
+from .functions import is_composite_quark_or_lepton
 
 from .functions import has_down
 from .functions import has_up
